pub struct ModelDownloadManager { /* private fields */ }Expand description
Manages voice model downloads, caching, and integrity verification.
Implementations
Sourceimpl ModelDownloadManager
impl ModelDownloadManager
Sourcepub fn is_cached(&self, model: &ModelInfo) -> bool
pub fn is_cached(&self, model: &ModelInfo) -> bool
Check if a model is already cached and valid.
Sourcepub fn model_path(&self, model_id: &str) -> PathBuf
pub fn model_path(&self, model_id: &str) -> PathBuf
Get the local path where a model would be cached.
Sourcepub fn available_stt_models() -> Vec<ModelInfo>
pub fn available_stt_models() -> Vec<ModelInfo>
List available STT models.
Sourcepub fn available_tts_models() -> Vec<ModelInfo>
pub fn available_tts_models() -> Vec<ModelInfo>
List available TTS models.
Sourcepub fn available_vad_models() -> Vec<ModelInfo>
pub fn available_vad_models() -> Vec<ModelInfo>
List available VAD models.