pub struct WakeDaemon { /* private fields */ }Expand description
Daemon that runs wake word detection in the background.
When the wake word is detected, the daemon can activate Talk Mode.
The daemon runs until cancelled via its CancellationToken.
Implementations
Sourceimpl WakeDaemon
impl WakeDaemon
Sourcepub fn new(config: WakeWordConfig) -> Result<Self, PluginError>
pub fn new(config: WakeWordConfig) -> Result<Self, PluginError>
Create a new wake daemon with the given configuration.
Sourcepub async fn run(
&mut self,
cancel: CancellationToken,
) -> Result<(), PluginError>
pub async fn run( &mut self, cancel: CancellationToken, ) -> Result<(), PluginError>
Run the daemon until cancelled.
STUB: Logs that the daemon is running and waits for cancellation. Real implementation will continuously capture audio and feed it to the wake word detector.
Sourcepub fn detector(&self) -> &WakeWordDetector
pub fn detector(&self) -> &WakeWordDetector
Get a reference to the underlying detector.